@@ -3,7 +3,6 @@ use warnings;
 use strict;
 use Getopt::Long;
 use Pod::Usage;
-use base q{Parse::Eyapp::TailSupport};
 
 sub lex {
   my $parser = shift;
@@ -31,9 +30,5 @@ sub semantic_error {
   $parser->YYError; 
 }
 
-sub TERMINAL::info {
-  $_[0]->{attr}[0]
-}
-
 1;
 
